@@ -14,6 +14,8 @@ class SamplingDTO(ModuleBaseDTO):
     def generate_code(self):
         pass
 
+class SurrogatesDTO(ModuleBaseDTO):
+    uqType: Literal['Surrogates'] = 'Surrogates'
 
 class ReliabilityDTO(ModuleBaseDTO):
     uqType: Literal['Reliability'] = 'Reliability'
